@@ -22,15 +22,6 @@
 
 
 
-
-
-
-
-
-
-
-
-
 
 
 
@@ -44,29 +35,29 @@
 -- Deprecation in 1.2.3
 CREATE OR REPLACE FUNCTION AsBinary(geometry)
 	RETURNS bytea
-	AS '$libdir/postgis-2.5','LWGEOM_asBinary'
+	AS '$libdir/postgis-3','LWGEOM_asBinary'
 	LANGUAGE 'c' IMMUTABLE STRICT;
 
 -- Deprecation in 1.2.3
 CREATE OR REPLACE FUNCTION AsBinary(geometry,text)
 	RETURNS bytea
-	AS '$libdir/postgis-2.5','LWGEOM_asBinary'
+	AS '$libdir/postgis-3','LWGEOM_asBinary'
 	LANGUAGE 'c' IMMUTABLE STRICT;
 
 -- Deprecation in 1.2.3
 CREATE OR REPLACE FUNCTION AsText(geometry)
 	RETURNS TEXT
-	AS '$libdir/postgis-2.5','LWGEOM_asText'
+	AS '$libdir/postgis-3','LWGEOM_asText'
 	LANGUAGE 'c' IMMUTABLE STRICT;
 
 -- Deprecation in 1.2.3
 CREATE OR REPLACE FUNCTION Estimated_Extent(text,text,text) RETURNS box2d AS
-	'$libdir/postgis-2.5', 'geometry_estimated_extent'
+	'$libdir/postgis-3', 'geometry_estimated_extent'
 	LANGUAGE 'c' IMMUTABLE STRICT SECURITY DEFINER;
 
 -- Deprecation in 1.2.3
 CREATE OR REPLACE FUNCTION Estimated_Extent(text,text) RETURNS box2d AS
-	'$libdir/postgis-2.5', 'geometry_estimated_extent'
+	'$libdir/postgis-3', 'geometry_estimated_extent'
 	LANGUAGE 'c' IMMUTABLE STRICT SECURITY DEFINER;
 
 -- Deprecation in 1.2.3
@@ -82,19 +73,19 @@ CREATE OR REPLACE FUNCTION GeomFromText(text)
 -- Deprecation in 1.2.3
 CREATE OR REPLACE FUNCTION ndims(geometry)
 	RETURNS smallint
-	AS '$libdir/postgis-2.5', 'LWGEOM_ndims'
+	AS '$libdir/postgis-3', 'LWGEOM_ndims'
 	LANGUAGE 'c' IMMUTABLE STRICT;
 
 -- Deprecation in 1.2.3
 CREATE OR REPLACE FUNCTION SetSRID(geometry,int4)
 	RETURNS geometry
-	AS '$libdir/postgis-2.5','LWGEOM_set_srid'
+	AS '$libdir/postgis-3','LWGEOM_set_srid'
 	LANGUAGE 'c' IMMUTABLE STRICT;
 
 -- Deprecation in 1.2.3
 CREATE OR REPLACE FUNCTION SRID(geometry)
 	RETURNS int4
-	AS '$libdir/postgis-2.5','LWGEOM_get_srid'
+	AS '$libdir/postgis-3','LWGEOM_get_srid'
 	LANGUAGE 'c' IMMUTABLE STRICT;
 
 -- Deprecation in 1.5.0
